<script setup>
import {$go} from "../../composables/goto";
</script>
<template>
    <AppLayout title="Clients">
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">
                <el-icon class="el-icon--left">
                    <Plus/>
                </el-icon>
                Add License
                <el-button size="small" type="primary" text @click="$go(route('licenses'))"
                           :active="route().current('clients.create')">
                    View Licenses
                </el-button>
            </h2>
        </template>
        <div>
            <div class="max-w-4xl mx-auto py-5 sm:px-6 mt-8 lg:px-8">
                <el-card>
                    <template #header>Enter license information</template>
                    <el-form :model="form" label-width="180px" :rules="rules" status-icon>
                        <el-form-item label="Project" prop="project">
                            <el-select ref="client" v-model="form.project" placeholder="Select a project" clearable
                                       style="width: 100%">
                                <el-option v-for="project in projects" :key="project.id" :label="project.name"
                                           :disabled="!project.active"
                                           :value="project.id">
                                     {{ project.name }}
                                </el-option>
                            </el-select>
                        </el-form-item>
                        <el-form-item label="Client" prop="client">
                            <el-select ref="client" v-model="form.client" placeholder="Select a client" clearable
                                       style="width: 100%">
                                <el-option v-for="client in clients" :key="client.id" :label="client.name"
                                           :disabled="client.active_license.active"
                                           :value="client.id">
                                    {{ client.name }}
                                    <small v-if="client.active_license.active"
                                           :class="[client.active_license.code === 1? 'text-green-400':'text-orange-400']">
                                        [{{ client.active_license.status }} LICENSE]</small>
                                </el-option>
                            </el-select>
                        </el-form-item>
                        <el-form-item ref="date" label="Duration of license" prop="date">
                            <el-date-picker value-format="YYYY-MM-DD" v-model="form.date" type="daterange" unlink-panels
                                            range-separator="To" start-placeholder="Start date"
                                            end-placeholder="End date" :shortcuts="shortcuts"/>
                        </el-form-item>
                        <hr/>
                        <div class="mt-5 flex flex-row right-0 text-right justify-between">
                            <el-button>Cancel</el-button>
                            <ConfirmsPassword @confirmed="addLicense">
                                <el-button :loading="form.processing" type="primary">Create License</el-button>
                            </ConfirmsPassword>
                        </div>
                    </el-form>
                </el-card>
            </div>
        </div>
    </AppLayout>
</template>

<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import {useForm} from '@inertiajs/inertia-vue3';
import ActionMessage from '@/Components/ActionMessage.vue';
import FormSection from '@/Components/FormSection.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import SectionTitle from "@/Components/SectionTitle.vue";
import NavLink from '@/Components/NavLink.vue';
import ConfirmsPassword from '@/Components/ConfirmsPassword.vue';
import {Tickets, Plus} from '@element-plus/icons-vue'
import Dropdown from "@/Components/Dropdown.vue";
import {reactive} from "vue";

export default {
    name: "License.Create",
    components: {
        Dropdown,
        SectionTitle,
        AppLayout,
        ActionMessage,
        FormSection,
        InputLabel,
        InputError,
        PrimaryButton,
        TextInput,
        NavLink, ConfirmsPassword, Tickets, Plus
    },
    data() {
        return {
            clients: this.$page.props.clients,
            projects: this.$page.props.projects,
            form: useForm({
                client: null,
                date: null,
                project: null
            }),
            rules: reactive({
                client: [{required: true, trigger: 'change',},],
                project: [{required: true, trigger: 'change',},],
                date: [{type: 'array', required: true, trigger: 'change'},],
            }),
            shortcuts: [
                {
                    text: 'One month',
                    value: () => {
                        const end = new Date()
                        const start = new Date()
                        end.setTime(start.getTime() + 3600 * 1000 * 24 * 31)
                        return [start, end]
                    },
                },
                {
                    text: 'Three months',
                    value: () => {
                        const end = new Date()
                        const start = new Date()
                        end.setTime(start.getTime() + 3600 * 1000 * 24 * 31 * 3)
                        return [start, end]
                    },
                },
                {
                    text: 'One year',
                    value: () => {
                        const end = new Date()
                        const start = new Date()
                        end.setTime(start.getTime() + 3600 * 1000 * 24 * 365)
                        return [start, end]
                    },
                },
                {
                    text: 'Two years',
                    value: () => {
                        const end = new Date()
                        const start = new Date()
                        end.setTime(start.getTime() + 3600 * 1000 * 24 * 365 * 2)
                        return [start, end]
                    },
                },
                {
                    text: 'Three years',
                    value: () => {
                        const start = new Date()
                        const end = new Date()
                        end.setTime(start.getTime() + 3600 * 1000 * 24 * 365 * 3)
                        return [start, end]
                    },
                }
            ]
        }
    },
    methods: {
        addLicense() {
            this.form.post(route('licenses.store'), {
                errorBag: 'addLicense',
                preserveScroll: true,
                onSuccess: () => this.form.reset(),
                onError: () => {
                    this.$refs[Object.keys(this.form.errors)[0]] && this.$refs[Object.keys(this.form.errors)[0]].focus()
                },
            });
        }
    }
}
</script>

<style scoped>

</style>
